importloc
=========

| *Import Python objects from arbitrary locations.*

.. include:: parts/badges.md
    :parser: commonmark

.. toctree::
    :maxdepth: 1
    :caption: Details
    :hidden:

    changelog


Functions
---------

.. currentmodule:: importloc

.. autosummary::

    module_from_file
    object_from_file
    object_from_module


Installation
------------

.. include:: parts/installation.md
    :parser: commonmark


API Reference
-------------

>>> from importloc import *

.. automodule:: importloc
    :members:
